@@ -47,37 +47,31 @@ gboolean is_predefined_profile(const gchar* profile_name)
     g_strcmp0(profile_name, "general")==0;
 }
 
-gchar* value_for_key(profileval_t* values, const gchar* key) 
-{ 
-  while(values && values->pv_key) 
-  { 
-    if(g_strcmp0(values->pv_key, key)==0) 
-      return values->pv_val; 
-    values = values++; 
-  } 
-  return NULL; 
-} 
-
-
 gchar* get_selected_profile_name(user_data_t* data)
 {
   GtkTreeIter iter;
-  hildon_touch_selector_get_selected(HILDON_TOUCH_SELECTOR(data->profiles_selector),
-				     0,
-				     &iter);
-  gchar* list_value;
-  gtk_tree_model_get(GTK_TREE_MODEL(data->profiles_list_store),
-		     &iter,1, &list_value,-1);
-
+  gchar* list_value = NULL;
+  if(hildon_touch_selector_get_selected(HILDON_TOUCH_SELECTOR(data->profiles_selector),
+					0,
+					&iter))
+  {
+    gtk_tree_model_get(GTK_TREE_MODEL(data->profiles_list_store),
+		       &iter,
+		       1, &list_value,
+		       -1);
+  }
   return list_value;
 }
+
 void
 edit_profile(GtkWidget* button, user_data_t *data)
 {
-  g_return_if_fail(data);
   gchar* profile_name = get_selected_profile_name(data);
-  show_editor_dialog(profile_name, data->main_dialog, data->sound_player);
-  g_free(profile_name);
+  if(profile_name != NULL)
+  {
+    show_editor_dialog(profile_name, data->main_dialog, data->sound_player);
+    g_free(profile_name);
+  }
 }
 
 gboolean 
@@ -87,11 +81,13 @@ is_profile_name_valid(const gchar* profile_name)
 }
 
 void
-fill_profiles_list_store(GtkListStore* list_store)
+fill_profiles_list_store(user_data_t* data)
 {
+  hildon_touch_selector_set_active(HILDON_TOUCH_SELECTOR(data->profiles_selector),0,-1);
+
   GtkTreeIter iter;
   gchar** profileList = profile_get_profiles();
-  gtk_list_store_clear(list_store);
+  gtk_list_store_clear(data->profiles_list_store);
   if(profileList)
   {
     gchar** profilePtr;
@@ -99,17 +95,17 @@ fill_profiles_list_store(GtkListStore* list_store)
 	*profilePtr;
 	profilePtr++)
     {
-      gtk_list_store_append(list_store, &iter);
-      gtk_list_store_set(list_store, &iter, 
-			 0, get_profile_display_name(*profilePtr), 
+      gtk_list_store_append(data->profiles_list_store, &iter);
+      gtk_list_store_set(data->profiles_list_store, &iter, 
+			 0, get_profile_display_name(*profilePtr),
 			 1, *profilePtr, 
 			 -1);
     }
   }
   profile_free_profiles(profileList);
+  hildon_touch_selector_set_active(HILDON_TOUCH_SELECTOR(data->profiles_selector),0,1);
 }
 
-
 gchar*
 ask_user_for_profile_name(user_data_t* data)
 {
@@ -137,7 +133,7 @@ ask_user_for_profile_name(user_data_t* data)
       name_is_valid = is_profile_name_valid(hildon_entry_get_text(HILDON_ENTRY(entry)));
     }
   }while(ret == GTK_RESPONSE_OK && !name_is_valid);
-  gchar* new_profile = g_strdup(hildon_entry_get_text(HILDON_ENTRY(entry)));
+  gchar* new_profile = g_strdup(gtk_entry_get_text(GTK_ENTRY(entry)));
   gtk_widget_destroy(dialog);
   if(ret == GTK_RESPONSE_OK)
   {
@@ -164,9 +160,10 @@ new_profile(GtkButton* button, user_data_t* data)
     g_free(cmd);
     if(ret)
     {
-      show_progress_bar(new_profile_name, data, TRUE, gtk_widget_get_toplevel(GTK_WIDGET(button)));
-      fill_profiles_list_store(data->profiles_list_store);
+      show_progress_bar(new_profile_name, 
+			data, TRUE, gtk_widget_get_toplevel(GTK_WIDGET(button)));
     }
+    g_free(new_profile_name);
   }
 }
 
@@ -185,21 +182,23 @@ void
 delete_profile(GtkButton* button, user_data_t* data)
 {
   gchar* list_value = get_selected_profile_name(data);
-  gchar* cmd = g_strdup_printf(RM_PROFILE_CMD, list_value);
-  gboolean ret = g_spawn_command_line_sync(cmd,
-					   NULL,
-					   NULL,
-					   NULL,
-					   NULL);
-  g_free(cmd);
-  if(ret)
+  if(list_value != NULL)
   {
-    activate_general_profile_on_delete_active(list_value);
-    show_progress_bar(g_strdup(list_value), data, FALSE, 
-		    gtk_widget_get_toplevel(GTK_WIDGET(button)));
+    gchar* cmd = g_strdup_printf(RM_PROFILE_CMD, list_value);
+    gboolean ret = g_spawn_command_line_sync(cmd,
+					     NULL,
+					     NULL,
+					     NULL,
+					     NULL);
+    g_free(cmd);
+    if(ret)
+    {
+      activate_general_profile_on_delete_active(list_value);
+      show_progress_bar(list_value, data, FALSE, 
+			gtk_widget_get_toplevel(GTK_WIDGET(button)));
+    }
+    g_free(list_value);
   }
-  g_free(list_value);
-  fill_profiles_list_store(data->profiles_list_store);
 }
 
 void
@@ -229,7 +228,7 @@ void
 show_hide_delete_button(HildonTouchSelector* selector, gint column, user_data_t* data)
 {
   gchar* profile_name = get_selected_profile_name(data);
-  if(is_predefined_profile(profile_name))
+  if(profile_name!= NULL && is_predefined_profile(profile_name))
   {
     gtk_widget_hide(data->profile_delete_button);
   }
@@ -249,21 +248,12 @@ add_main_dialog_profile_list(user_data_t* data)
 						 G_TYPE_STRING,
 						 G_TYPE_STRING);
 
-  fill_profiles_list_store(data->profiles_list_store);
-
-  data->profiles_selector = hildon_touch_selector_new();
-  renderer = gtk_cell_renderer_text_new();
-
-  column = hildon_touch_selector_append_column(HILDON_TOUCH_SELECTOR(data->profiles_selector),
-					       GTK_TREE_MODEL(data->profiles_list_store),
-					       renderer,
-					       "text", 0, NULL);
-  g_object_set(G_OBJECT(column),
-	       "text-column",
-	       0,
-	       NULL);
+  data->profiles_selector = hildon_touch_selector_new_text();
+  hildon_touch_selector_set_model(HILDON_TOUCH_SELECTOR(data->profiles_selector),
+				  0,
+				  GTK_TREE_MODEL(data->profiles_list_store));  
+  fill_profiles_list_store(data);
   g_signal_connect(data->profiles_selector, "changed", G_CALLBACK(show_hide_delete_button), data);
-
   gtk_container_add(GTK_CONTAINER(GTK_DIALOG(data->main_dialog)->vbox), data->profiles_selector);
 }
 
@@ -290,8 +280,9 @@ void init_sound_player(user_data_t* data)
 		  "module-stream-restore.id",
 		  "x-maemo-applet-profiles");
   g_object_set(G_OBJECT(pulsesink), "proplist", proplist, NULL);
+  //  pa_proplist_free(proplist);
   data->sound_player = gst_element_factory_make("playbin2", "Media Player");
-  g_object_set(data->sound_player, "audio-sink", pulsesink);
+  g_object_set(data->sound_player, "audio-sink", pulsesink, NULL);
 }
 
 osso_return_t execute(osso_context_t *osso,
@@ -315,8 +306,9 @@ osso_return_t execute(osso_context_t *osso,
     //ignored
   }
   gtk_widget_destroy(GTK_WIDGET(app_data->main_dialog));
-  
   gst_object_unref(app_data->sound_player);
+  gst_object_unref(app_data->profiles_list_store);
+  g_free(app_data);
   return OSSO_OK;
 }
 
